@@ -8,16 +8,16 @@ pub enum Delimiter {
 
 impl Delimiter {
     #[inline]
-    pub fn into_node(self, range: Option<OffsetRange>) -> ASTNode {
+    pub fn into_node(self, range: MaybeRanged) -> ASTNode {
         ASTNode { value: ASTKind::Delimiter(box self), range }
     }
 }
 
 impl ASTKind {
-    pub fn raw_html_inline(msg: impl Into<String>, range: Option<OffsetRange>) -> ASTNode {
+    pub fn raw_html_inline(msg: impl Into<String>, range: MaybeRanged) -> ASTNode {
         Delimiter::HTMLRawBlock(msg.into()).into_node(range)
     }
-    pub fn raw_html_block(msg: impl Into<String>, range: Option<OffsetRange>) -> ASTNode {
+    pub fn raw_html_block(msg: impl Into<String>, range: MaybeRanged) -> ASTNode {
         TextKind::HTMLRawInline(msg.into()).into_node(range)
     }
 }
